@@ -3,7 +3,7 @@ from django.contrib.auth.models import PermissionsMixin
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
-from swap_user.managers.email import EmailManager
+from swap_user.to_email.managers import EmailManager
 
 
 class AbstractEmailUser(PermissionsMixin, DjangoAbstractBaseUser):
@@ -19,13 +19,11 @@ class AbstractEmailUser(PermissionsMixin, DjangoAbstractBaseUser):
     Provides attributes:
     - USERNAME_FIELD
     - EMAIL_FIELD
-    - REQUIRED_FIELDS
+
+    REQUIRED_FIELDS by default will include USERNAME_FIELD and password.
     """
 
-    email = models.EmailField(
-        verbose_name=_("email address"),
-        unique=True,
-    )
+    email = models.EmailField(verbose_name=_("email address"), unique=True,)
     is_active = models.BooleanField(
         verbose_name=_("active"),
         default=False,
